version 9.2
clear
set more off
use FCTBfinal.dta


***************************************************
* Generating 0-E-1 event windows as well as the
* the estimation window
* 
* Summarizing event markers into broader categories
***************************************************


*--------------------------------
* Combining some event categories
*--------------------------------


* Events induced by the European Commission 

quietly gen commission = 0
quietly replace commission = 1 if actec1==1
label var commission "Commission induced event"


* Events induced by the European Court of Justice

quietly gen ecj = 0
quietly replace ecj = 1 if actecj1==1
label var ecj "ECJ induced event"

* Events induced by the Council

gen council = 0
quietly replace council = 1 if  actcouncil1==1
label var council "Intergovernmental actor"



*---------------------------------------
* Establishing variables to capture 9/11
*---------------------------------------


* Dummy

gen nineeleven = 0
quietly replace nineeleven = 1 if t==1747
label var nineeleven "9/11 Dummy"


* Event and post-event day

gen nineeleven01 = 0
quietly replace nineeleven01 = 1 if t==1747 | t==1748
label var nineeleven01 "9/11: 0-E-1 window"



* Five day window

gen nineeleven04 = 0
quietly replace nineeleven04 = 1 if t==1747 | t==1748 |t==1749 | t==1750 | t==1751
label var nineeleven04 "9/11: 0-E-4 window"


* Two weeks following the incident (until 25 Sep 2001)

gen nineeleven010 = 0
quietly replace nineeleven010 = 1 if t==1747 | t==1748 |t==1749 | t==1750 | t==1751 | t==1752 | t==1753 | t==1754 | t==1755 | t==1756 | t==1757 
label var nineeleven010 "9/11: 0-E-10 window"


*--------------------------------------------------
* Generating the estimation window 
* which excludes 5 days before and after each event
*--------------------------------------------------

sort t
quietly tsset t

gen estwin = 1								/* This variable marks the estimation window based on a distance of 10 days to each event */

local i=0
while `i'<=10 {													/* This loop starts with the event date (i==0), works five days onwards */
quietly replace estwin=0 if event[_n-`i']==1					/* and sets the Estimation Window marker to zero during this time */
local i=`i'+1
}

local i=10								/* This loop starts 10 days prior to an event (i==10), works on to one day prior (i==1)*/
while `i'>0 {						
quietly replace estwin=0 if event[_n+`i']==1 					/* and sets the Estimation Window marker to zero during this time */
local i=`i'-1
}

label var estwin "Estimation window"



*---------------------------------------------------------------
* Establishing (truncated) event windows
*---------------------------------------------------------------

* The following routine establish the 0-E-1 window for each event and event-type
* 
* The windows are truncated if events may overlap (distances to the
* preceeding and to the following event are stored in variables dist1 and dist2). 
*
* In these cases, priority is always given to post-event days.


sort t
quietly tsset t


* 0-E-1: Two day event windows including one  post event day
************************************************************

gen event11 = 0									/* This variable marks the (truncated) 0-1-1 event window */
gen ev_id_11 = .								/* This variable will store the ev_id of the event corresponding to the event window */								
quietly replace event11 = 1 if event==1 						/* Including the event day */
quietly replace ev_id_11 = ev_id if event==1
quietly replace event11 = 1 if event[_n-1]==1 & dist2[_n-1]>=2				/* Including the post-event day into the event window only if the following event is at least 2 trading days away */
quietly replace ev_id_11 = ev_id[_n-1] if event[_n-1]==1 & dist2[_n-1]>=2

label var event11 "0-E-1 event window"
label var ev_id_11 "0-E-1 Event ID"

drop event
ren event11 event

drop ev_id
ren ev_id_11 ev_id


	* Commission Events

	gen commission11 = 0								
	quietly replace commission11 = 1 if commission==1 						
	quietly replace commission11 = 1 if commission[_n-1]==1 & dist2[_n-1]>=2
	
	label var commission11 "Commission: 0-E-1 window"
	
	drop commission
	ren commission11 commission
	
	* ECJ Events

	gen ecj11 = 0								
	quietly replace ecj11 = 1 if ecj==1 						
	quietly replace ecj11 = 1 if ecj[_n-1]==1 & dist2[_n-1]>=2
	
	label var ecj11 "ECJ: 0-E-1 window"
	
	drop ecj
	ren ecj11 ecj

	
	* Council events
	
	gen council11 = 0								
	quietly replace council11 = 1 if council==1 						
	quietly replace council11 = 1 if council[_n-1]==1 & dist2[_n-1]>=2

	label var council11 "Council event: 0-E-1 window"
	
	drop council
	ren council11 council
	

	* Formal events

	gen formal11 = 0								
	quietly replace formal11 = 1 if formal==1 						
	quietly replace formal11 = 1 if formal[_n-1]==1 & dist2[_n-1]>=2

	label var formal11 "Formal: 0-E-1 window"
	
	drop formal
	ren formal11 formal

	* Informal events

	gen informal11 = 0								
	quietly replace informal11 = 1 if informal==1 						
	quietly replace informal11 = 1 if informal[_n-1]==1 & dist2[_n-1]>=2

	label var informal11 "Informal: 0-E-1 window"
	
	drop informal
	ren informal11 informal

	* Carry FT page forward
	
	replace page = page[_n-1] if event[_n-1]==1 & event==1 
	
	* Carry distance to previous event forward
	
	replace dist1 = dist1[_n-1] if event[_n-1]==1 & event==1 
	
	
* Removing some coded variables not used in further analysis

drop act* *formal direc


*--------
* Saving
*--------

quietly compress
save FCTBwind.dta, replace

exit
