version 10
set more off
clear

use FCTB.dta, clear


*-----------------------------------------------
* Seemingly Unrelated Regressions
* for individual companies and individual events
*-----------------------------------------------

* SUR including test for independence of residuals across airline companies
* Setup for individual airlines follwos the best fitting market model during estimation window

sureg	(dafr event1-event27 dsbf250 dfuelro nineeleven04) ///
		(dbaw event1-event27 dftas dfuelro nineeleven04) /// 
		(ddlh event1-event27 ddaxk dfuelro nineeleven04, noconstant) ///
		(daza event1-event27 dmibtel l.dfuelro nineeleven04) /// 
		(daua event1-event27 datx dfuelro nineeleven04) ///
		(dfin event1-event27 dhex25 nineeleven04) ///
		(dklm event1-event27 daex l.dfuelro nineeleven04) ///
		(dsas event1-event27 domx nineeleven04) ///
		(daal event1-event27 dnya dfuelny nineeleven04) /// 
		(dcoa event1-event27 dnya l.dfuelny nineeleven04) /// 
		, corr

estimates store surevents
quietly estout surevents using sureventsresults0E1.csv, cells(b(star fmt(3))) stard unstack stats(r2 chi2 p) legend style(fixed) delim(";") replace


* Joint tests over all airline companies for hypothesis all event effects = 0

tempname memhold
tempfile jointeventtests0E1


postfile `memhold' event chi2 df p using jointeventtests0E1, replace
forvalues i = 1(1)27 {
	quietly test event`i'
	post `memhold' (`i') (r(chi2)) (r(df)) (r(p))
	}

postclose `memhold'

use jointeventtests0E1.dta, clear
outsheet using jointeventtests0E1.csv, delim(";") replace
erase jointeventtests0E1.dta


*-------------------------------------------------------------
* Plotting Cumulative Average Abnormnal Returns across events
*-------------------------------------------------------------

use FCTB.dta, clear


* Generating abnormal airline returns along market models identified earlier

reg dafr dsbf250 dfuelro, robust
predict ar_afr, resid

reg daza dmibtel l.dfuelro, robust
predict ar_aza, resid

reg daua datx dfuelro, robust
predict ar_aua, resid

reg dbaw dftas dfuelro, robust
predict ar_baw, resid

reg dfin dhex25, robust
predict ar_fin, resid

reg dibe dsmsi, robust noconstant
predict ar_ibe, resid

reg dklm daex l.dfuelro, robust
predict ar_klm, resid

reg ddlh ddaxk dfuelro, robust noconstant
predict ar_dlh, resid

reg dsas domx, robust
predict ar_sas, resid

reg dswr dssmi, robust
predict ar_swr, resid

reg daal dnya dfuelny, robust
predict ar_aal, resid

reg dcoa dnya l.dfuelny, robust
predict ar_coa, resid


* Collapsing to one obs per event

keep if event
collapse (mean) ar_*, by(ev_id) /* averag AR in event window */

* Cumulate

sort ev_id

foreach al in ar_aza ar_aua ar_baw ar_fin ar_klm ar_dlh ar_sas ar_aal ar_coa ar_afr {
	gen c`al'=0
	replace c`al'=`al' in 1
	replace c`al'=c`al'[_n-1]+`al' in 2/27
	}

	
* Generate Portfolios

egen car_big = rowmean(car_dlh car_afr car_baw)
label var car_big "Large EU carriers"

egen car_small = rowmean(car_aza car_aua car_fin car_sas car_klm)
label var car_small "Small EU carriers"

egen car_us = rowmean(car_aal car_coa)
label var car_us "US carriers"

* Plot

line car_big car_small car_us ev_id, ytitle("Cumulative average abnormal returns") xline(14 22) /* marking initiation of judicial action and final court verdict */
graph save caar_plot.gph, replace


exit

